.. _whatsnew_100rc3:

1.0.0rc3 (September 16, 2020)
-----------------------------

This is the third 1.0 release candidate.


API Changes
~~~~~~~~~~~
* Added quantile score and skill score metrics
  :py:func:`solarforecastarbiter.metrics.probabilistic.quantile_score`
  :py:func:`solarforecastarbiter.metrics.probabilistic.quantile_skill_score`
  (:issue:`520`) (:pull:`530`)

Enhancements
~~~~~~~~~~~~
* Update DOE ARM reference dataset with previously missing irradiance data.
  This change introduced changes to the `extra_parameters` fields of DOE ARM
  reference sites stored in the Solar Forecast Arbiter, and existing sites
  must be updated with new fields. See the
  `solarforecastarbiter/io/reference_observations/arm_reference_sites.json` for
  examples and explanation of the new `extra_parameters` format. (:pull:`536`)

* Add :py:func:`solarforecastarbiter.metrics.deterministic.relative_euclidean_distance`
  (:issue:`542`, :pull:`549`)

* Add :py:func:`solarforecastarbiter.plotting.timeseries.generate_probabilistic_forecast_figure`
  to create timeseries plots for probabilistic forecasts. It should be noted
  that this new function generates a Plotly figure, as opposed to Bokeh figures
  which are generated by other functions in this module.
  (:issue:`550`, :pull:`551`)

* Add opacity to scatter plot markers to improve visibility. (:issue:`547`)

* Add support for kwargs in
  :py:func:`solarforecastarbiter.io.api.request_cli_access_token`. (:issue:`483`)

Bug fixes
~~~~~~~~~
* Fix PVDAQ time zones. (:issue:`537`) (:pull:`540`)
* Fix missing PVDAQ sites. (:issue:`539`) (:pull:`540`)
* Converted NOAA USCRN site elevation to meters. (:pull:`545`)
* Fix non-deterministic order and color in time series and scatter plots.
  (:issue:`548`) (:pull:`562`)
* Make scatter plot aspect ratio 1:1 and set same number of grid lines on
  the x and y axes. (:issue:`419`) (:pull:`562`)
* Render ``W/m^2`` with a superscript in time series and scatter plots.
  (:pull:`562`)
* Render report preprocessing results with friendly names (e.g. Event Forecast)
  instead of class names (e.g. EventForecast). (:issue:`406`)
* Correct incorrect timeseries plots used in reports for probabilistic
  forecasts with axis y. This bug was introduced in Release Candidate 2.
  (:issue:`568`) (:pull:`569`)
* Adjust abbreviation of long reference forecast names to first abbreviate
  some words and then cut entire words from the site name (:issue:`521`)
  (:pull:`571`)
* Fixed issue with UO SRML reference data fetching that resulted in posting
  NaN values for data that had not yet been included in SRML files.
  (:issue:`543`)(:pull:`572` )

Contributors
~~~~~~~~~~~~

* Will Holmgren (:ghuser:`wholmgren`)
* Leland Boeman (:ghuser:`lboeman`)
* Cliff Hansen (:ghuser:`cwhanse`)
* Tony Lorenzo (:ghuser:`alorenzo175`)
* Justin Sharp (:ghuser:`MrWindAndSolar`)
* Aidan Tuohy
* Adam Wigington (:ghuser:`awig`)
* David Larson (:ghuser:`dplarson`)
* Will Hobbs (:ghuser:`williamhobbs`)
